@@ -3,30 +3,30 @@
 #' This function allows you to pool local revenue for school districts at either
 #' the county or state level to see the effects on individual districts.
 #' @param data_year Four digit year of master data to pull in. Options include
-#'   2013- 2018. Defaults to 2018.
+#'   2013- 2019. Defaults to 2019.
 #' @param pooling_level Character string indicating the level of local revenue
 #'   pooling. Either county or state. Defaults to county.
 #' @keywords borders revenue pooling EdBuild
-#' @usage big_borders(data_year= "2018", pooling_level = "county")
+#' @usage big_borders(data_year= "2019", pooling_level = "county")
 #' @import dplyr magrittr stringr
 #' @return A dataframe with 17 variables where each observation is a school district.
 #' @seealso \code{\link{masterpull}}, \code{\link{master_codebook}}
 #' @export
 #' @examples
 #' \donttest{state_pool <- big_borders(
-#'            data_year = "2018",
+#'            data_year = "2019",
 #'            pooling_level = "state"
 #'            )}
 
 
-big_borders = function(data_year = "2018", pooling_level="county") {
+big_borders = function(data_year = "2019", pooling_level="county") {
 
   if (as.numeric(data_year)<2013) {
-    message("Error: Master datasets are only available for years 2013 through 2018")
+    message("Error: Master datasets are only available for years 2013 through 2019")
   }
 
-  else if (as.numeric(data_year)>2018) {
-    message("Error: Master datasets are only available for years 2013 through 2018")
+  else if (as.numeric(data_year)>2019) {
+    message("Error: Master datasets are only available for years 2013 through 2019")
   }
 
   else if (as.numeric(data_year)==2013){
@@ -68,6 +68,13 @@ big_borders = function(data_year = "2018", pooling_level="county") {
     master <- read.csv(file = url, stringsAsFactors = FALSE) %>%
       dplyr::mutate(FRL_rate = dFRL/dEnroll_district)
 
+  }
+  else if(as.numeric(data_year)==2019) {
+    url = "https://s3.amazonaws.com/data.edbuild.org/public/Processed+Data/Master/2019/full_data_19_geo_exc.csv"
+    master <- read.csv(file = url, stringsAsFactors = FALSE) %>%
+      dplyr::mutate(dFRL = NA,
+                    FRL_rate = dFRL/dEnroll_district)
+
   }
 
   county_master <- master %>% ## assigning counties to the districts that do not have CCD counties but that have F33 revenue data, the assigned counties come from the geo intersection
